summaryrefslogtreecommitdiff
path: root/src/webtab/webtab.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/webtab/webtab.cpp')
-rw-r--r--src/webtab/webtab.cpp5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/webtab/webtab.cpp b/src/webtab/webtab.cpp
index bc40ecca..1a4c0fe2 100644
--- a/src/webtab/webtab.cpp
+++ b/src/webtab/webtab.cpp
@@ -293,7 +293,10 @@ void WebTab::showMessageBar()
void WebTab::loadFinished()
{
- // add page to history
+ // add page to history, if not in private browsing mode
+ if (page()->settings()->testAttribute(QWebSettings::PrivateBrowsingEnabled))
+ return;
+
QString pageTitle = (page() && page()->isOnRekonqPage()) ? url().url() : m_webView->title();
HistoryManager::self()->addHistoryEntry(url(), pageTitle);
}